@@ -79,6 +79,7 @@ class PageOptions : public AbstractPage
         QComboBox *CBResolution;
         QSpinBox *windowWidthEdit;
         QSpinBox *windowHeightEdit;
+        QLabel *winLabelX;
         QComboBox *CBStereoMode;
         QCheckBox *CBFrontendSound;
         QCheckBox *CBFrontendMusic;
@@ -110,6 +111,7 @@ class PageOptions : public AbstractPage
         QLineEdit *editNetNick;
         QLineEdit *editNetPassword;
         QSlider *SLQuality;
+        QSpinBox *SLZoom;
         QCheckBox *CBFrontendEffects;
         QComboBox * cbProxyType;
         QSpinBox * sbProxyPort;
