@@ -32,6 +32,7 @@ RoomNamePrompt::RoomNamePrompt(QWidget* parent, const QString & roomName) : QDia
     setModal(true);
     setWindowFlags(Qt::Sheet);
     setWindowModality(Qt::WindowModal);
+    setWindowTitle(tr("Create room"));
     setMinimumSize(360, 130);
     resize(360, 180);
     setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
@@ -47,7 +48,8 @@ RoomNamePrompt::RoomNamePrompt(QWidget* parent, const QString & roomName) : QDia
     // Input box
     leRoomName = new QLineEdit(this);
     leRoomName->setText(roomName);
-    leRoomName->setMaxLength(59); // It didn't like 60 :(
+    //leRoomName->setMaxLength(59); // It didn't like 60 :(
+    leRoomName->setMaxLength(40);
     leRoomName->setStyleSheet("QLineEdit { padding: 3px; }");
     leRoomName->selectAll();
     dialogLayout->addWidget(leRoomName);
