@@ -65,6 +65,7 @@ handleCmd_NotEntered ["PASSWORD", passwd] = do
     if clientProto cl < 48 && passwd == webPassword cl then
         return $ JoinLobby : [AnswerClients [sendChan cl] ["ADMIN_ACCESS"] | isAdministrator cl]
         else
+        -- String is parsed by frontend, do not localize!
         return [ByeClient "Authentication failed"]
 
 
@@ -81,6 +82,7 @@ handleCmd_NotEntered ["PASSWORD", passwd, clientSalt] = do
             , JoinLobby
             ]
         else
+        -- String is parsed by frontend, do not localize!
         return [ByeClient "Authentication failed"]
     where
         h = B.pack . showDigest . sha1 . BL.fromChunks
@@ -99,4 +101,6 @@ handleCmd_NotEntered ["CHECKER", protoNum, newNick, password] = do
         parsedProto = readInt_ protoNum
 #endif
 
-handleCmd_NotEntered _ = return [ProtocolError "Incorrect command (state: not entered)"]
+handleCmd_NotEntered (s:_) = return [ProtocolError $ "Incorrect command '" `B.append` s `B.append` "' (state: not entered)"]
+
+handleCmd_NotEntered [] = return [ProtocolError "Empty command (state: not entered)"]
\ No newline at end of file
