@@ -9,10 +9,10 @@ download_and_zip (){
 }
 download_and_zip http://www.xelification.com/tmp/jpeg.zip jpeg
 download_and_zip http://www.xelification.com/tmp/png.zip png
-download_and_zip http://www.libsdl.org/projects/SDL_image/release/SDL_image-1.2.12.zip SDL_image
-download_and_zip http://www.libsdl.org/projects/SDL_mixer/release/SDL_mixer-1.2.12.zip SDL_mixer
+download_and_zip http://www.libsdl.org/tmp/SDL_image/release/SDL2_image-2.0.0.zip SDL_image
+download_and_zip http://www.libsdl.org/tmp/SDL_mixer/release/SDL2_mixer-2.0.0.zip SDL_mixer
 download_and_zip http://www.xelification.com/tmp/mikmod.zip mikmod #temporary url since the libsdl.org site doesn't work at the moment
-download_and_zip http://www.xelification.com/tmp/SDL_net.zip SDL_net
+download_and_zip http://www.libsdl.org/projects/SDL_net/release/SDL_net-1.2.8.zip SDL_net
 download_and_zip http://www.libsdl.org/projects/SDL_ttf/release/SDL_ttf-2.0.11.zip SDL_ttf
-download_and_zip http://www.libsdl.org/tmp/SDL-1.3.zip SDL
+download_and_zip http://www.libsdl.org/tmp/release/SDL2-2.0.0.zip SDL
 
