@@ -1,6 +1,6 @@
 ------------------- ABOUT ----------------------
 --
--- Hog Solo has to catch the other hog in order
+-- The hero has to catch the other hog in order
 -- to get informations about the origin of Pr. Hogevil
 
 HedgewarsScriptLoad("/Scripts/Locale.lua")
@@ -13,9 +13,16 @@ local missionName = loc("Chasing the blue hog")
 local challengeObjectives = loc("Use the rope in order to catch the blue hedgehog").."|"..
 	loc("You have to stand very close to him")
 local currentPosition = 1
+local raceSectionStarted = false
+local runnerCaught = false
 local previousTimeLeft = 0
 local startChallenge = false
 local winningTime = nil
+local currentTime = 0
+local runnerTime = 0
+local record
+local lostGame = false
+local heroHurt = false
 -- dialogs
 local dialog01 = {}
 local dialog02 = {}
@@ -27,17 +34,21 @@ local goals = {
 local hero = {
 	name = loc("Hog Solo"),
 	x = 1300,
-	y = 850
+	y = 948
 }
 local runner = {
 	name = loc("Crazy Runner"),
 	places = {
-		{x = 1400,y = 850, turnTime = 0},
+		{x = 1400,y = 904, turnTime = 0},
 		{x = 3880,y = 33, turnTime = 30000},
 		{x = 250,y = 1780, turnTime = 25000},
 		{x = 3850,y = 1940, turnTime = 20000},
 	}
 }
+local runnerTimeTotal = 0
+for i=1, #runner.places do
+	runnerTimeTotal = runnerTimeTotal + runner.places[i].turnTime
+end
 -- teams
 local teamA = {
 	name = loc("Hog Solo"),
@@ -63,16 +74,18 @@ function onGameInit()
 	WaterRise = 0
 	HealthDecrease = 0
 
-	-- Hog Solo
-	AddTeam(teamA.name, teamA.color, "Simple", "Island", "Default", "hedgewars")
-	hero.gear = AddHog(hero.name, 0, 1, "war_desertgrenadier1")
+	-- Hero
+	teamA.name = AddMissionTeam(teamA.color)
+	hero.gear = AddMissionHog(1)
+	hero.name = GetHogName(hero.gear)
 	AnimSetGearPosition(hero.gear, hero.x, hero.y)
 	-- Crazy Runner
-	AddTeam(teamB.name, teamB.color, "ring", "Island", "Default", "cm_sonic")
+	teamB.name = AddTeam(teamB.name, teamB.color, "ring", "Island", "Default_qau", "cm_sonic")
 	runner.gear = AddHog(runner.name, 0, 100, "sth_Sonic")
 	AnimSetGearPosition(runner.gear, runner.places[1].x, runner.places[1].y)
 	HogTurnLeft(runner.gear, true)
 
+	record = tonumber(GetCampaignVar("FastestBlueHogCatch"))
 	initCheckpoint("moon02")
 
 	AnimInit(true)
@@ -84,7 +97,11 @@ function onGameStart()
 	FollowGear(hero.gear)
 
 	AddEvent(onHeroDeath, {hero.gear}, heroDeath, {hero.gear}, 0)
+	AddEvent(onRunnerDeath, {runner.gear}, runnerDeath, {runner.gear}, 0)
 
+	if record ~= nil then
+		goals[dialog01][3] = goals[dialog01][3] .. "|" .. string.format(loc("Personal best: %.3f seconds"), record/1000)
+	end
 	AddAmmo(hero.gear, amRope, 1)
 
 	SendHealthStatsOff()
@@ -110,17 +127,32 @@ function onNewTurn()
 	if startChallenge and currentPosition < 5 then
 		if CurrentHedgehog ~= hero.gear then
 			EndTurn(true)
+			runnerTime = runnerTime + runner.places[currentPosition].turnTime
+			SetTeamLabel(teamB.name, string.format(loc("%.1fs"), runnerTime/1000))
 		else
-			if GetAmmoCount(hero.gear, amRope) == 0  then
-				lose()
-			end
 			SetWeapon(amRope)
 			SetTurnTimeLeft(runner.places[currentPosition].turnTime + previousTimeLeft)
 			previousTimeLeft = 0
+			if currentPosition > 1 then
+				raceSectionStarted = true
+			end
+			runnerCaught = false
 		end
 	end
 end
 
+function onEndTurn()
+	if raceSectionStarted and currentPosition > 1 and currentPosition < 5 then
+		if CurrentHedgehog == hero.gear and (not runnerCaught) and (not heroHurt) then
+			-- sndBoring played manually because lose calls EndGame, which suppresses
+			-- the taunt.
+			PlaySound(sndBoring, hero.gear)
+			lose()
+		end
+	end
+	raceSectionStarted = false
+end
+
 function onGameTick()
 	AnimUnWait()
 	if ShowAnimation() == false then
@@ -128,9 +160,15 @@ function onGameTick()
 	end
 	ExecuteAfterAnimations()
 	CheckEvents()
+	if GetHealth(hero.gear) and CurrentHedgehog == hero.gear and startChallenge and currentPosition < 5 and currentPosition > 1 and ReadyTimeLeft == 0 and band(GetState(CurrentHedgehog), gstHHDriven) ~= 0 then
+		currentTime = currentTime + 1
+	end
 end
 
 function onGameTick20()
+	if startChallenge and currentPosition < 5 and currentPosition > 1 and CurrentHedgehog == hero.gear and ReadyTimeLeft == 0 and band(GetState(CurrentHedgehog), gstHHDriven) ~= 0 then
+		SetTeamLabel(teamA.name, string.format(loc("%.1fs"), currentTime/1000))
+	end
 	if GetHealth(hero.gear) and startChallenge and isHeroNextToRunner() and currentPosition < 5 then
 		moveRunner()
 	end
@@ -142,6 +180,12 @@ function onPrecise()
 	end
 end
 
+function onGearDamage(gear)
+	if gear == hero.gear then
+		heroHurt = true
+	end
+end
+
 -------------- EVENTS ------------------
 
 function onHeroDeath(gear)
@@ -151,12 +195,23 @@ function onHeroDeath(gear)
 	return false
 end
 
+function onRunnerDeath(gear)
+	if not GetHealth(runner.gear) then
+		return true
+	end
+	return false
+end
+
 -------------- ACTIONS ------------------
 
 function heroDeath(gear)
 	lose()
 end
 
+function runnerDeath(gear)
+	loseRunnerDeath()
+end
+
 -------------- ANIMATIONS ------------------
 
 function Skipanim(anim)
@@ -181,7 +236,7 @@ function AnimationSetup()
 	table.insert(dialog01, {func = AnimSay, args = {runner.gear, loc("Let's go!"), SAY_SAY, 2000}})
 	table.insert(dialog01, {func = ShowMission, args = goals[dialog01]})
 	table.insert(dialog01, {func = moveRunner, args = {}})
-	-- DIALOG 02 - Hog Solo story
+	-- DIALOG 02 - Professor Hogevil story
 	AddSkipFunction(dialog02, Skipanim, {dialog02})
 	table.insert(dialog02, {func = AnimWait, args = {hero.gear, 3200}})
 	table.insert(dialog02, {func = AnimCaption, args = {hero.gear, loc("The truth about Professor Hogevil"), 5000}})
@@ -201,9 +256,10 @@ end
 ------------- other functions ---------------
 
 function isHeroNextToRunner()
-	if GetGearType(hero.gear) == gtHedgehog and GetGearType(runner.gear) == gtHedgehog and
+	if IsHogAlive(hero.gear) and IsHogAlive(runner.gear) and
 			math.abs(GetX(hero.gear) - GetX(runner.gear)) < 75 and
-			math.abs(GetY(hero.gear) - GetY(runner.gear)) < 75 and StoppedGear(hero.gear) then
+			math.abs(GetY(hero.gear) - GetY(runner.gear)) < 75 and
+			StoppedGear(hero.gear) and StoppedGear(runner.gear) then
 		return true
 	end
 	return false
@@ -218,13 +274,9 @@ function moveRunner()
 		AddAnim(dialog02)
 
 		-- Update time record
-		local baseTime = 0
-		for i=1, #runner.places do
-			baseTime = baseTime + runner.places[i].turnTime
-		end
-		winningTime = baseTime - TurnTimeLeft
+		winningTime = runnerTimeTotal - TurnTimeLeft
+		SetTeamLabel(teamA.name, string.format(loc("%.3fs"), winningTime/1000))
 		SendStat(siCustomAchievement, string.format(loc("You have managed to catch the blue hedgehog in %.3f seconds."), winningTime/1000))
-		local record = tonumber(GetCampaignVar("FastestBlueHogCatch"))
 		if record ~= nil and winningTime >= record then
 			SendStat(siCustomAchievement, string.format(loc("Your personal best time so far: %.3f seconds"), record/1000))
 		end
@@ -242,11 +294,11 @@ function moveRunner()
 		end
 		AddAmmo(hero.gear, amRope, 1)
 		if currentPosition ~= 1 then
-			PlaySound(sndVictory)
 			if currentPosition > 1 and currentPosition < 4 then
 				AnimCaption(hero.gear, loc("Go, get him again!"), 3000)
 				AnimSay(runner.gear, loc("You got me!"), SAY_SAY, 3000)
 			end
+			runnerCaught = true
 			previousTimeLeft = TurnTimeLeft
 		end
 		currentPosition = currentPosition + 1
@@ -257,19 +309,44 @@ function moveRunner()
 end
 
 function lose()
+	if lostGame then
+		return
+	end
+	lostGame = true
 	SendStat(siGameResult, loc("Too slow! Try again ..."))
 	SendStat(siCustomAchievement, loc("You have to catch the other hog 3 times."))
 	SendStat(siCustomAchievement, loc("The time that you have left when you reach the blue hedgehog will be added to the next turn."))
 	SendStat(siCustomAchievement, loc("Each turn you'll have only one rope to use."))
 	SendStat(siCustomAchievement, loc("You'll lose if you die or if your time is up."))
-	sendSimpleTeamRankings({teamB.name, teamA.name})
+	SendStat(siPointType, "!TIME")
+	SendStat(siPlayerKills, tostring(runnerTimeTotal), teamB.name)
+	SendStat(siPointType, "!EMPTY")
+	SendStat(siPlayerKills, "0", teamA.name)
+	EndGame()
+end
+
+function loseRunnerDeath()
+	if lostGame then
+		return
+	end
+	lostGame = true
+	SendStat(siGameResult, loc("Race failed!"))
+	SendStat(siCustomAchievement, loc("The other hog has died, he should have survived!"))
+	SendStat(siCustomAchievement, loc("You have to catch the other hog 3 times."))
+	SendStat(siTeamRank, "1")
+	SendStat(siPlayerKills, tostring(GetTeamStats(teamB.name).Kills), teamB.name)
+	SendStat(siTeamRank, "1")
+	SendStat(siPlayerKills, tostring(GetTeamStats(teamA.name).Kills), teamA.name)
 	EndGame()
 end
 
 function win()
 	SendStat(siGameResult, loc("Congratulations, you are the fastest!"))
 	-- siCustomAchievements were added earlier
-	sendSimpleTeamRankings({teamA.name, teamB.name})
+	SendStat(siPointType, "!TIME")
+	SendStat(siPlayerKills, tostring(winningTime), teamA.name)
+	SendStat(siPointType, "!TIME")
+	SendStat(siPlayerKills, tostring(runnerTimeTotal), teamB.name)
 	SaveCampaignVar("Mission13Won", "true")
 	checkAllMissionsCompleted()
 	EndGame()
