@@ -696,7 +696,11 @@ function DrawBlip(gear)
 	end
 
 	local baseColor, radius, alpha
-	if getGearValue(gear, "frozen") then
+	if CurrentHedgehog == nil or band(GetState(CurrentHedgehog), gstHHDriven) == 0 then
+		radius = 40
+		baseColor = 0xFFFFFFFF
+		alpha = 255
+	elseif getGearValue(gear, "frozen") then
 		radius = 25
 		baseColor = 0xFFFFFFFF
 		alpha = math.min(255, rAlpha+127)
@@ -720,6 +724,7 @@ function TrackRadarBlip(gear)
 	g2X, g2Y = GetX(gear), GetY(gear)
 	q = g1X - g2X
 	w = g1Y - g2Y
+	-- Floating point operations are safe, it's only for visuals
 	r = math.sqrt( (q*q) + (w*w) )	--alternate
 
 	RCX = getGearValue(gear,"RX")
@@ -848,9 +853,21 @@ function UnfreezeCrates()
 
 end
 
+function onCaseDrop()
+	local crates
+	if roundN == 100 then
+		allowCrate = crateGearsInGame < maxCrates
+		crates = CheckCrateConditions()
+	end
+	if type(crates) == "table" and #crates > 0 and CurrentHedgehog then
+		PlaySound(sndReinforce, CurrentHedgehog)
+	end
+end
+
 function CheckCrateConditions()
 
 	local crateSpawn = AreCratesUnlocked()
+	local crates = {}
 
 	if crateSpawn == true and crateSpawned == false then
 		UnfreezeCrates()
@@ -861,7 +878,7 @@ function CheckCrateConditions()
 				toSpawn = maxCrates - cratesInGame
 			end
 			for i=1,toSpawn do
-				SpawnSupplyCrate(0, 0, weapons[1+GetRandom(#weapons)] )
+				table.insert(crates, SpawnSupplyCrate(0, 0, weapons[1+GetRandom(#weapons)]))
 			end
 			rPingTimer = 0
 			rAlpha = 0
@@ -871,6 +888,7 @@ function CheckCrateConditions()
 		end
 	end
 
+	return crates
 end
 
 function onGearWaterSkip(gear)
@@ -935,6 +953,9 @@ end
 
 function HandleBorderEffects()
 
+	if CurrentHedgehog == nil or band(GetState(CurrentHedgehog), gstHHDriven) == 0 then
+		return
+	end
 	effectTimer = effectTimer + 1
 	if effectTimer > 15 then --25
 
@@ -956,7 +977,7 @@ function PlaceWarn()
 	AddCaption(loc("Please place your hedgehog first!"), msgColorWarn, capgrpMessage2)
 end
 
-function onLJump()
+function AcceptConfiguration()
 	if roundN == 1 then
 		PlaySound(sndPlaced)
 		SetInputMask(0xFFFFFFFF)
@@ -980,6 +1001,12 @@ function onLJump()
 		end
 		PlaySound(sndYesSir, CurrentHedgehog)
 		FinalizeMenu()
+	end
+end
+
+function onLJump()
+	if roundN == 1 then
+		AcceptConfiguration()
 	elseif roundN == 2 then
 		PlaceWarn()
 	elseif roundN == 100 then
@@ -1255,7 +1282,8 @@ function onGameStart()
 	end
 
 	if useMenu then
-		ShowMission(loc("Wall to wall"), loc("Please wait …"), "", 2, 300000)
+		ShowMission(loc("Wall to wall"), loc("Please wait …"), "", 2, 0)
+		HideMission()
 		UpdateMenu()
 	else
 		if GetGameFlag(gfPlaceHog) then
@@ -1269,6 +1297,17 @@ function onGameStart()
 	end
 end
 
+function onEndTurn()
+	crateSpawned = false
+	crateCollected = false
+	wallsLeft = #wTouched
+	for i = 1, #wTouched do
+		wTouched[i] = false
+	end
+	hasSurfed = false
+	allWallsHit = false
+end
+
 function onNewTurn()
 	turnsCount = turnsCount + 1
 
@@ -1290,25 +1329,15 @@ function onNewTurn()
 		end
 	end
 
-	wallsLeft = #wTouched
-
-	for i = 1, #wTouched do
-		wTouched[i] = false
-	end
-
-	hasSurfed = false
-	allWallsHit = false
-	crateCollected = false
-
-	crateSpawned = false
-
 	if roundN == 100 then
-		allowCrate = crateGearsInGame < maxCrates
 
 		local teamName = GetHogTeamName(CurrentHedgehog)
 
 		-- Restore team's radar mode
 		radarMode = getTeamValue(teamName, "radarMode")
+		if radarMode == nil then
+			radarMode = 0
+		end
 
 		if not AreCratesUnlocked() then
 			FreezeCrates()
@@ -1332,8 +1361,6 @@ function onNewTurn()
 			setTeamValue(teamName, "skipPenalty", false)
 		end
 
-	else
-		allowCrate = false
 	end
 
 	if roundN == 1 then
@@ -1343,6 +1370,9 @@ function onNewTurn()
 		UpdateMenu()
 		AddCaption(string.format(loc("%s may choose the rules."), GetHogTeamName(CurrentHedgehog)), msgColorTech, capgrpGameState)
 		HandleStartingStage()
+		if GetHogLevel(CurrentHedgehog) ~= 0 then
+			AcceptConfiguration()
+		end
 	end
 
 end
@@ -1559,7 +1589,7 @@ function HandleStartingStage()
 				preMenuCfg..
 				missionComment ..
 				postMenuCfg ..
-				"", 2, 9999000, true
+				"", 3, 9999000, true
 				)
 
 end
@@ -1573,8 +1603,10 @@ function onGameTick()
 			gTimer = 1
 
 			if roundN == 100 then
-				CheckForWallCollision()
-				CheckCrateConditions()
+				if band(GetState(CurrentHedgehog), gstHHDriven) ~= 0 then
+					CheckForWallCollision()
+					CheckCrateConditions()
+				end
 
 				if (GetGearType(GetFollowGear()) == gtCase) then
 					FollowGear(CurrentHedgehog)
@@ -1620,11 +1652,12 @@ function onGameTick()
 
 		end
 
-		HandleBorderEffects()
-		HandleCircles()
 
 	end
 
+	HandleBorderEffects()
+	HandleCircles()
+
 end
 
 local menuRepeatTimer = 0
@@ -1654,7 +1687,7 @@ function onGearAdd(gear)
 		if vg then
 			table.insert(rCirc, vg)
 			setGearValue(gear,"CIRC",vg)
-			SetVisualGearValues(vg, 0, 0, 100, 255, 1, 10, 0, 40, 3, 0xff00ffff)
+			SetVisualGearValues(vg, 0, 0, 100, 255, 1, 10, 0, 40, 3, 0x0)
 		end
 		setGearValue(gear,"RX",0)
 		setGearValue(gear,"RY",0)
